require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe "Facehugger" do
  context "new" do
    before :all do
      VCR.insert_cassette 'new', :record => :new_episodes
    end

    after :all do
      VCR.eject_cassette
    end

    let(:facehugger) { Facehugger.new }

    describe "when valid API key and no API secret" do
      it {
        facehugger.api_key = FACE_ACCOUNT['api_key']
        facehugger.should_not be_valid
      }
    end

    describe "when no API key and valid API secret" do
      it {
        facehugger.api_secret = FACE_ACCOUNT['api_secret']
        facehugger.should_not be_valid
      }
    end

    describe "when valid API key and valid API secret" do
      it {
        facehugger.api_key = FACE_ACCOUNT['api_key']
        facehugger.api_secret = FACE_ACCOUNT['api_secret']
        facehugger.should be_valid
      }
    end
  end

  context "faces_detect" do
    before :all do
      VCR.insert_cassette 'faces_detect', :record => :new_episodes
    end

    after :all do
      VCR.eject_cassette
    end

    let(:facehugger) {
      Facehugger.new(:api_key => FACE_ACCOUNT['api_key'],
                     :api_secret => FACE_ACCOUNT['api_secret'])
    }

    describe "valid image" do
      it {
        photos = facehugger.faces_detect(:urls => "http://cdn.bleacherreport.net/images_root/slides/photos/002/097/419/mimi_knoop_original.jpg")
        photos.should_not be_nil
      }
    end

    describe "valid image upload" do
      it {
        photos = facehugger.faces_detect(:file => "data/group-of-people.jpg")
        photos.should_not be_nil
      }
    end
  end
end